[![Build Status](https://travis-ci.org/bluesky/ophyd.svg)](https://travis-ci.org/bluesky/ophyd)

| Name | Downloads | Version | Platforms |
| --- | --- | --- | --- |
| [![Conda Recipe](https://img.shields.io/badge/recipe-ophyd-green.svg)](https://anaconda.org/nsls2forge/ophyd) | [![Conda Downloads](https://img.shields.io/conda/dn/nsls2forge/ophyd.svg)](https://anaconda.org/nsls2forge/ophyd) | [![Conda Version](https://img.shields.io/conda/vn/nsls2forge/ophyd.svg)](https://anaconda.org/nsls2forge/ophyd) | [![Conda Platforms](https://img.shields.io/conda/pn/nsls2forge/ophyd.svg)](https://anaconda.org/nsls2forge/ophyd) |

Ophyd - EPICS Client Abstractions
=================================

[Documentation](https://blueskyproject.io/ophyd/)

## Conda Recipe

Install the most recent conda build: `conda install ophyd -c nsls2forge`

Find the recipe [here](https://github.com/nsls-ii-forge/ophyd-feedstock/tree/master/recipe/meta.yaml).
